@@ -32,8 +32,6 @@ struct _CcIllustratedRow
   GtkBox            *picture_box;
   CcMaskPaintable   *picture_mask;
   gchar             *resource_path;
-
-  GtkMediaStream    *media_stream;
 };
 
 G_DEFINE_FINAL_TYPE (CcIllustratedRow, cc_illustrated_row, CC_TYPE_VERTICAL_ROW);
@@ -50,34 +48,33 @@ static GParamSpec *props[N_PROPS] = { NULL, };
 static void
 on_picture_leave_cb (CcIllustratedRow *self)
 {
-  if (self->media_stream != NULL)
-    {
-      gtk_media_stream_set_loop (self->media_stream, FALSE);
-      gtk_media_stream_pause (self->media_stream);
-    }
+  GtkMediaStream *stream;
+  GdkPaintable *paintable;
+
+  paintable = cc_mask_paintable_get_paintable (self->picture_mask);
+
+  if (!GTK_IS_MEDIA_STREAM (paintable))
+    return;
+
+  stream = GTK_MEDIA_STREAM (paintable);
+  gtk_media_stream_set_loop (stream, FALSE);
+  gtk_media_stream_pause (stream);
 }
 
 static void
 on_picture_hover_cb (CcIllustratedRow *self)
 {
-  if (self->media_stream != NULL)
-    {
-      gtk_media_stream_set_loop (self->media_stream, TRUE);
-      gtk_media_stream_play (self->media_stream);
-    }
-}
+  GtkMediaStream *stream;
+  GdkPaintable *paintable;
 
-static void
-update_mask_color (CcIllustratedRow *self)
-{
-  AdwStyleManager *style_manager = adw_style_manager_get_default ();
-  AdwAccentColor color;
-  GdkRGBA rgba;
+  paintable = cc_mask_paintable_get_paintable (self->picture_mask);
 
-  color = adw_style_manager_get_accent_color (style_manager);
-  adw_accent_color_to_rgba (color, &rgba);
+  if (!GTK_IS_MEDIA_STREAM (paintable))
+    return;
 
-  cc_mask_paintable_set_rgba (self->picture_mask, &rgba);
+  stream = GTK_MEDIA_STREAM (paintable);
+  gtk_media_stream_set_loop (stream, TRUE);
+  gtk_media_stream_play (stream);
 }
 
 static void
@@ -144,6 +141,8 @@ cc_illustrated_row_class_init (CcIllustratedRowClass *klass)
 
   g_object_class_install_properties (object_class, N_PROPS, props);
 
+  g_type_ensure (CC_TYPE_MASK_PAINTABLE);
+
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/control-center/common/cc-illustrated-row.ui");
 
   gtk_widget_class_bind_template_child (widget_class, CcIllustratedRow, picture_box);
@@ -153,43 +152,11 @@ cc_illustrated_row_class_init (CcIllustratedRowClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, on_picture_leave_cb);
 }
 
-static void
-reload_illustration (CcIllustratedRow *self)
-{
-  g_autoptr (GdkPaintable) paintable = NULL;
-  int scale;
-
-  if (self->media_stream != NULL)
-    return;
-
-  scale = gtk_widget_get_scale_factor (GTK_WIDGET (self));
-  paintable = cc_texture_new_from_resource_scaled (self->resource_path, scale);
-
-  cc_mask_paintable_set_paintable (self->picture_mask, paintable);
-}
-
 static void
 cc_illustrated_row_init (CcIllustratedRow *self)
 {
-  AdwStyleManager *style_manager = adw_style_manager_get_default ();
-
   gtk_widget_init_template (GTK_WIDGET (self));
-  gtk_widget_set_name (GTK_WIDGET (self), "illustrated-row");
-  gtk_widget_add_css_class (GTK_WIDGET (self), "illustrated-row");
-
-  update_mask_color (self);
-
-  g_signal_connect_object (style_manager, "notify::dark",
-                           G_CALLBACK (update_mask_color), self,
-                           G_CONNECT_SWAPPED);
-  g_signal_connect_object (style_manager, "notify::accent-color",
-                           G_CALLBACK (update_mask_color), self,
-                           G_CONNECT_SWAPPED);
-
-  g_signal_connect_swapped (self, "map",
-                            G_CALLBACK (reload_illustration), self);
-  g_signal_connect_swapped (self, "notify::scale-factor",
-                            G_CALLBACK (reload_illustration), self);
+  gtk_widget_add_css_class (GTK_WIDGET (self), "illustrated");
 }
 
 void
@@ -198,18 +165,9 @@ cc_illustrated_row_set_resource (CcIllustratedRow *self,
 {
   g_return_if_fail (CC_IS_ILLUSTRATED_ROW (self));
 
-  if (self->media_stream != NULL)
-    g_clear_object (&self->media_stream);
-
   g_set_str (&self->resource_path, resource_path);
 
-  if (g_str_has_suffix (resource_path, ".svg"))
-    reload_illustration (self);
-  else
-    {
-      self->media_stream = gtk_media_file_new_for_resource (self->resource_path);
-      cc_mask_paintable_set_paintable (self->picture_mask, GDK_PAINTABLE (self->media_stream));
-    }
+  cc_mask_paintable_set_resource_scaled (self->picture_mask, resource_path, GTK_WIDGET (self));
 
   gtk_widget_set_visible (GTK_WIDGET (self->picture_box),
                           self->resource_path != NULL &&
