@@ -88,7 +88,7 @@ connect_wifi_page (CEPageWifi *self)
         g_signal_connect_object (self->mac_combo, "changed", G_CALLBACK (ce_page_changed), self, G_CONNECT_SWAPPED);
 
         cloned_mac = nm_setting_wireless_get_cloned_mac_address (self->setting);
-        ce_page_setup_cloned_mac_combo (self->cloned_mac_combo, cloned_mac);
+        ce_page_setup_cloned_mac_combo (self->cloned_mac_combo, cloned_mac, TRUE);
         g_signal_connect_object (self->cloned_mac_combo, "changed", G_CALLBACK (ce_page_changed), self, G_CONNECT_SWAPPED);
 }
 
