@@ -1151,7 +1151,7 @@ net_device_wifi_new (CcPanel *panel, NMClient *client, NMDevice *device)
         g_signal_connect_object (device, "state-changed", G_CALLBACK (nm_device_wifi_refresh_ui), self, G_CONNECT_SWAPPED);
 
         /* Set up the main Visible Networks list */
-        list = cc_wifi_connection_list_new (client, NM_DEVICE_WIFI (device), TRUE, TRUE, FALSE, FALSE);
+        list = cc_wifi_connection_list_new (client, NM_DEVICE_WIFI (device), TRUE, TRUE, FALSE, FALSE, TRUE);
         cc_wifi_connection_list_set_placeholder_text (list, _("Searching for networks…"));
         gtk_box_append (self->listbox_box, GTK_WIDGET (list));
 
@@ -1168,7 +1168,7 @@ net_device_wifi_new (CcPanel *panel, NMClient *client, NMDevice *device)
                                  G_CALLBACK(nm_client_on_permission_change), self, G_CONNECT_SWAPPED);
 
         /* Set up the Saved Networks list */
-        list = cc_wifi_connection_list_new (self->client, NM_DEVICE_WIFI (device), FALSE, FALSE, FALSE, TRUE);
+        list = cc_wifi_connection_list_new (self->client, NM_DEVICE_WIFI (device), FALSE, FALSE, FALSE, TRUE, FALSE);
         cc_wifi_connection_list_set_placeholder_text (list, _("No saved networks"));
         self->saved_networks_list = g_object_ref_sink (list);
         adw_preferences_group_add (self->saved_networks_box, GTK_WIDGET (list));
