@@ -90,4 +90,19 @@ GCancellable *cc_panel_get_cancellable    (CcPanel     *panel);
 
 void          cc_panel_deactivate         (CcPanel     *panel);
 
+void          cc_panel_add_subpage        (CcPanel     *panel,
+                                           const gchar *page_tag,
+                                           AdwNavigationPage *subpage);
+
+void          cc_panel_add_static_subpage (CcPanel     *panel,
+                                           const gchar *page_name,
+                                           GType        page_type);
+
+void          cc_panel_push_subpage       (CcPanel     *panel,
+                                           AdwNavigationPage *subpage);
+
+void          cc_panel_pop_visible_subpage (CcPanel    *panel);
+
+AdwNavigationPage *cc_panel_get_visible_subpage (CcPanel *panel);
+
 G_END_DECLS
